ResourceError

Enum ResourceError 

pub enum ResourceError {
    StaleHandle {
        handle: ResourceId,
    },
    NotOwner {
        handle: ResourceId,
        expected_owner: String,
        actual_caller: String,
    },
    NotAllocated {
        handle: ResourceId,
    },
    BorrowsOutstanding {
        handle: ResourceId,
        borrow_count: u32,
    },
    MutableLeaseActive {
        handle: ResourceId,
    },
    ReadOnlyLeasesActive {
        handle: ResourceId,
    },
    BudgetExceeded {
        component: ComponentId,
        current_bytes: u64,
        requested_bytes: u64,
        budget_bytes: u64,
    },
    AllocationFailed {
        requested_capacity: u32,
        reason: String,
    },
    CapacityExceeded {
        handle: ResourceId,
        capacity: u32,
        attempted_size: u64,
    },
    OutOfBounds {
        handle: ResourceId,
        offset: u64,
        buffer_size: u64,
    },
}
Resource management errors.

Error code range: E0300–E0399.

Variants



StaleHandle

The resource handle refers to a slot that has been freed and reused.

Fields

handle: ResourceId

The stale handle.



NotOwner

The caller is not the owner of the resource.

Fields

handle: ResourceId

The resource handle.

expected_owner: String

The expected owner.

actual_caller: String

The actual caller.



NotAllocated

The resource is not currently allocated (still in pool).

Fields

handle: ResourceId

The resource handle.



BorrowsOutstanding

Outstanding borrows prevent the requested operation.

Fields

handle: ResourceId

The resource handle.

borrow_count: u32

Number of outstanding borrows.



MutableLeaseActive

A mutable lease is active, preventing the requested operation.

Fields

handle: ResourceId

The resource handle.



ReadOnlyLeasesActive

Read-only leases are active, preventing the requested operation.

Fields

handle: ResourceId

The resource handle.



BudgetExceeded

The component’s memory budget would be exceeded.

Fields

component: ComponentId

The component exceeding its budget.

current_bytes: u64

Current memory usage in bytes.

requested_bytes: u64

Requested additional bytes.

budget_bytes: u64

Total budget in bytes.



AllocationFailed

Buffer pool is exhausted and system allocator fallback failed.

Fields

requested_capacity: u32

The requested buffer capacity.

reason: String

The reason for failure.



CapacityExceeded

The write would exceed the buffer’s capacity.

Fields

handle: ResourceId

The resource handle.

capacity: u32

The buffer capacity.

attempted_size: u64

The attempted write size.



OutOfBounds

The offset is out of bounds.

Fields

handle: ResourceId

The resource handle.

offset: u64

The invalid offset.

buffer_size: u64

The buffer size.